==> alfresco-repository-23.7.0.4-sources.jar: org/alfresco/service/cmr/subscriptions/PrivateSubscriptionListException.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.cmr.subscriptions;

import org.alfresco.error.AlfrescoRuntimeException;

/**
 * This exception is thrown if a subscription list is private and the accessing
 * user is not allowed to see it.
 * 
 * @author Florian Mueller
 * @since 4.0
 */
public class PrivateSubscriptionListException extends AlfrescoRuntimeException
{
    private static final long serialVersionUID = 6971869799749343887L;

    public PrivateSubscriptionListException(String msg)
    {
        super(msg);
    }

    public PrivateSubscriptionListException(String msg, Throwable cause)
    {
        super(msg, cause);
    }
}

==> alfresco-repository-25.2.1.2-sources.jar: org/alfresco/service/cmr/subscriptions/PrivateSubscriptionListException.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.cmr.subscriptions;

import org.alfresco.error.AlfrescoRuntimeException;

/**
 * This exception is thrown if a subscription list is private and the accessing user is not allowed to see it.
 * 
 * @author Florian Mueller
 * @since 4.0
 */
public class PrivateSubscriptionListException extends AlfrescoRuntimeException
{
    private static final long serialVersionUID = 6971869799749343887L;

    public PrivateSubscriptionListException(String msg)
    {
        super(msg);
    }

    public PrivateSubscriptionListException(String msg, Throwable cause)
    {
        super(msg, cause);
    }
}
